---
name: Feature request
about: Suggest a new feature or enhancement
title: ''
labels: enhancement
assignees: ''

---

<!--
Thank you for suggesting an improvement to Archimedes!
Before submitting, please check if a similar feature request already exists.

Please only use the issue submission process for clearly-defined, narrowly-scoped requests.
For more general queries or requests, please use the Discussions page.
-->

**Is your feature request related to a problem? Please describe.**
A clear and concise description of what the problem is. Ex. I'm always frustrated when [...]

**Describe the solution you'd like**
A clear and concise description of what you want to happen.

**Describe alternatives you've considered**
A clear and concise description of any alternative solutions or features you've considered.

**Additional context**
Add any other context or screenshots about the feature request here.
